Wrapper

Struct Wrapper 

pub struct Wrapper;
Simplifies calling into the service

Implementations

Source

impl Wrapper

pub const SERVICE: AccountNumber

The account this service normally runs on, “packages”

pub fn call() -> Actions<ServiceCaller>

Call another service.

This method returns an object which has methods (one per action) which call another service and return the result from the call. This method is only usable by services.

This method defaults sender to crate::get_sender and service to “packages”.

pub fn call_to(service: AccountNumber) -> Actions<ServiceCaller>

Call another service.

This method returns an object which has methods (one per action) which call another service and return the result from the call. This method is only usable by services.

This method defaults sender to crate::get_sender.

pub fn call_from(sender: AccountNumber) -> Actions<ServiceCaller>

Call another service.

This method returns an object which has methods (one per action) which call another service and return the result from the call. This method is only usable by services.

This method defaults service to “packages”.

pub fn call_from_to( sender: AccountNumber, service: AccountNumber, ) -> Actions<ServiceCaller>

Call another service.

This method returns an object which has methods (one per action) which call another service and return the result from the call. This method is only usable by services.

pub fn call_as(sender: AccountNumber) -> Actions<RunAsCaller>

Call another service using runAs.

This method returns an object which has methods (one per action) which call another service via runAs and return the result from the call. The action will run with sender set to the provided account. This method defaults service to “packages”.

This will fail unless certain conditions are met. See runAs documentation for more details.

pub fn call_as_extend( sender: AccountNumber, allowed_actions: Vec<ServiceMethod>, ) -> Actions<RunAsCaller>

Call another service using runAs.

This method returns an object which has methods (one per action) which call another service via runAs and return the result from the call. The action will run with sender set to the provided account. This method defaults service to “packages”.

This will fail unless certain conditions are met. See runAs documentation for more details.

This method also accepts allowedActions for nested runAs calls.

pub fn rpc() -> Actions<ServiceCaller>

Call another service.

This method returns an object which has methods (one per action) which call another service and return the result from the call. This method is only usable by services.

This method defaults sender to crate::get_sender and service to “packages”.

pub fn push(chain: &Chain) -> Actions<ChainPusher<'_>>

push transactions to psibase::Chain.

This method returns an object which has methods (one per action) which push transactions to a test chain and return a psibase::ChainResult or psibase::ChainEmptyResult. This final object can verify success or failure and can retrieve the return value, if any.

This method defaults both sender and service to “packages”.

pub fn push_to( chain: &Chain, service: AccountNumber, ) -> Actions<ChainPusher<'_>>

push transactions to psibase::Chain.

This method returns an object which has methods (one per action) which push transactions to a test chain and return a psibase::ChainResult or psibase::ChainEmptyResult. This final object can verify success or failure and can retrieve the return value, if any.

This method defaults sender to “packages”.

pub fn push_from( chain: &Chain, sender: AccountNumber, ) -> Actions<ChainPusher<'_>>

push transactions to psibase::Chain.

This method returns an object which has methods (one per action) which push transactions to a test chain and return a psibase::ChainResult or psibase::ChainEmptyResult. This final object can verify success or failure and can retrieve the return value, if any.

This method defaults service to “packages”.

pub fn push_from_to( chain: &Chain, sender: AccountNumber, service: AccountNumber, ) -> Actions<ChainPusher<'_>>

push transactions to psibase::Chain.

This method returns an object which has methods (one per action) which push transactions to a test chain and return a psibase::ChainResult or psibase::ChainEmptyResult. This final object can verify success or failure and can retrieve the return value, if any.

pub fn pack() -> Actions<ActionPacker>

Pack actions into psibase::Action.

This method returns an object which has methods (one per action) which pack the action’s arguments using fracpack and return a psibase::Action. The pack_* series of functions is mainly useful to applications which push transactions to blockchains.

This method defaults both sender and service to “packages”.

pub fn pack_to(service: AccountNumber) -> Actions<ActionPacker>

Pack actions into psibase::Action.

This method returns an object which has methods (one per action) which pack the action’s arguments using fracpack and return a psibase::Action. The pack_* series of functions is mainly useful to applications which push transactions to blockchains.

This method defaults sender to “packages”.

pub fn pack_from(sender: AccountNumber) -> Actions<ActionPacker>

Pack actions into psibase::Action.

This method returns an object which has methods (one per action) which pack the action’s arguments using fracpack and return a psibase::Action. The pack_* series of functions is mainly useful to applications which push transactions to blockchains.

This method defaults service to “packages”.

pub fn pack_from_to( sender: AccountNumber, service: AccountNumber, ) -> Actions<ActionPacker>

Pack actions into psibase::Action.

This method returns an object which has methods (one per action) which pack the action’s arguments using fracpack and return a psibase::Action. The pack_* series of functions is mainly useful to applications which push transactions to blockchains.

pub fn emit() -> EmitEvent

Emit events from a service.

This method defaults service to “packages”.

pub fn emit_from(sender: AccountNumber) -> EmitEvent

Emit events from a service.