pub struct PublicKey {
pub data: PublicKeyEnum,
}Fields
data: PublicKeyEnumTrait Implementations
sourceimpl<'de> Deserialize<'de> for PublicKey
impl<'de> Deserialize<'de> for PublicKey
sourcefn deserialize<D: Deserializer<'de>>(deserializer: D) -> Result<Self, D::Error>
fn deserialize<D: Deserializer<'de>>(deserializer: D) -> Result<Self, D::Error>
Deserialize this value from the given Serde deserializer. Read more
sourceimpl InputType for PublicKey
impl InputType for PublicKey
type RawValueType = PublicKey
type RawValueType = PublicKey
The raw type used for validator. Read more
sourcefn create_type_info(registry: &mut Registry) -> String
fn create_type_info(registry: &mut Registry) -> String
Create type information in the registry and return qualified typename.
sourcefn parse(value: Option<Value>) -> InputValueResult<Self>
fn parse(value: Option<Value>) -> InputValueResult<Self>
Parse from
Value. None represents undefined.sourcefn as_raw_value(&self) -> Option<&Self::RawValueType>
fn as_raw_value(&self) -> Option<&Self::RawValueType>
Returns a reference to the raw value.
sourcefn qualified_type_name() -> String
fn qualified_type_name() -> String
Qualified typename.
sourceimpl OutputType for PublicKey
impl OutputType for PublicKey
sourcefn create_type_info(registry: &mut Registry) -> String
fn create_type_info(registry: &mut Registry) -> String
Create type information in the registry and return qualified typename.
sourcefn resolve<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
_: &'life1 ContextSelectionSet<'life2>,
_field: &'life3 Positioned<Field>
) -> Pin<Box<dyn Future<Output = ServerResult<Value>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn resolve<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
_: &'life1 ContextSelectionSet<'life2>,
_field: &'life3 Positioned<Field>
) -> Pin<Box<dyn Future<Output = ServerResult<Value>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Resolve an output value to
async_graphql::Value.sourcefn qualified_type_name() -> String
fn qualified_type_name() -> String
Qualified typename.
sourceimpl ScalarType for PublicKey
impl ScalarType for PublicKey
sourceimpl<'a> Unpack<'a> for PublicKey
impl<'a> Unpack<'a> for PublicKey
sourcefn unpack(src: &'a [u8], pos: &mut u32) -> Result<Self>
fn unpack(src: &'a [u8], pos: &mut u32) -> Result<Self>
Convert from fracpack format. Also verifies the integrity of the data. Read more
sourcefn verify(src: &'a [u8], pos: &mut u32) -> Result<()>
fn verify(src: &'a [u8], pos: &mut u32) -> Result<()>
Verify the integrity of fracpack data. You don’t need to call this if
using [Pack::unpack] since it verifies integrity during unpack.